import { Body, Controller, Delete, Get, Param, Patch, Post, UploadedFiles, UseGuards, UseInterceptors } from "@nestjs/common";
import { Constants } from "src/utils/constants";
import { AdminAuthGuard } from "src/core/guards/admin-auth.guard";
import { CreateHomePageAboutSectionDto } from "./dto/create-home-page-about-section.dto";
import { UpdateHomePageAboutSectionDto } from "./dto/update-home-page-about-section.dto";
import { HomePageAboutSectionService } from "./home-page-about-section.service";

@Controller({ path: "home-page-about-section", version: Constants.API_VERSION_1 })

export class HomePageAboutSectionController {
    constructor(private readonly service: HomePageAboutSectionService) { }

    @Post()
    @UseGuards(AdminAuthGuard)
    create(
        @Body() dto: CreateHomePageAboutSectionDto,
    ) {
        return this.service.create(dto);
    }

    @Get()
    @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }

    @Get(":id")
    @UseGuards(AdminAuthGuard)
    findOne(@Param("id") id: string) {
        return this.service.findOne(id);
    }

    @Patch("/:id")
    @UseGuards(AdminAuthGuard)
    update(
        @Param("id") id: string,
        @Body() dto: UpdateHomePageAboutSectionDto,
    ) {
        return this.service.update(id, dto);
    }

    @Delete(":id")
    @UseGuards(AdminAuthGuard)
    async remove(@Param("id") id: string) {
        return await this.service.remove(id);
    }
}
