import { EntityRepository, getConnection, Repository } from "typeorm";
import { HomePageHeroSectionEntity } from "./entities/home-page-hero-section.entity";
import { CreateHomePageHeroSectionDto } from "./dto/create-home-page-hero-section.dto";
import { UpdateHomePageHeroSectionDto } from "./dto/update-home-page-hero-section.dto";

@EntityRepository(HomePageHeroSectionEntity)
export class HomePageHeroSectionRepository extends Repository<HomePageHeroSectionEntity> {
    async createEntity(dto: CreateHomePageHeroSectionDto): Promise<HomePageHeroSectionEntity | Error> {
        try {
            const {
                title,
                description,
                buttonLink,
                buttonText,
                image
            } = dto;
            const entity = this.create({
                title,
                description,
                buttonLink,
                buttonText,
                image
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<HomePageHeroSectionEntity | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateHomePageHeroSectionDto): Promise<HomePageHeroSectionEntity | Error> {
        try {
            await this.update(id, {
                title: dto.title,
                description: dto.description,
                buttonLink: dto.buttonLink,
                buttonText: dto.buttonText,
                image: dto.image
            });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<HomePageHeroSectionEntity[] | Error> {
        try {
            return await this.find({
                where: { ...query, isDeleted: false }
            });
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(HomePageHeroSectionEntity)
                .set({ isDeleted: true })
                .where("id = :id", { id: id })
                .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }
}