import {Body, Controller, Delete, Get, Param, Patch, Post, UseGuards} from "@nestjs/common";
import {Constants} from "src/utils/constants";
import {AdminAuthGuard} from "src/core/guards/admin-auth.guard";
import {NewsletterService} from "./newsletter.service";
import {CreateNewsletterDto} from "./dto/create-newsletter.dto";
import {UpdateNewsletterDto} from "./dto/update-newsletter.dto";

@Controller({path: "newsletter", version: Constants.API_VERSION_1})

export class NewsletterController {
    constructor(private readonly service: NewsletterService) {}

    @Post()
    // @UseGuards(AdminAuthGuard)
    create(@Body() dto: CreateNewsletterDto) {
        return this.service.create(dto);
    }

    @Get()
    @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }

    @Get(":id")
    @UseGuards(AdminAuthGuard)
    findOne(@Param("id") id: string) {
        return this.service.findOne(id);
    }

    @Patch("/:id")
    @UseGuards(AdminAuthGuard)
    update(@Param("id") id: string, @Body() dto: UpdateNewsletterDto) {
        return this.service.update(id, dto);
    }

    @Delete(":id")
    @UseGuards(AdminAuthGuard)
    async remove(@Param("id") id: string) {
        return await this.service.remove(id);
    }
}
